@@ -49,10 +49,10 @@ DatabaseBrowser::DatabaseBrowser( TQString _database, TQWidget *parent, const ch
 
     database = _database;
 
-    connect( table, TQT_SIGNAL( cursorChanged( TQSql::Op ) ),
-             SqlTables::getInstance(), TQT_SIGNAL( tablesChanged() ) );
+    connect( table, TQ_SIGNAL( cursorChanged( TQSql::Op ) ),
+             SqlTables::getInstance(), TQ_SIGNAL( tablesChanged() ) );
 
-    connect( TQT_TQOBJECT(this), TQT_SIGNAL( connectedSQL() ), this, TQT_SLOT( setupSql() ) );
+    connect( this, TQ_SIGNAL( connectedSQL() ), this, TQ_SLOT( setupSql() ) );
 
     findDlg = 0;
     
@@ -81,10 +81,10 @@ void DatabaseBrowser::setupActions()
     DSMainWindow::setupActions();
     TDEPopupMenu* editMenu = new TDEPopupMenu( this );
 
-    TDEAction* acut = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT( cut() ), actionCollection() );
-    TDEAction* acopy = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( copy() ), actionCollection() );
-    TDEAction* apaste = KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT( paste() ), actionCollection() );
-    TDEAction* afind = KStdAction::find( TQT_TQOBJECT(this), TQT_SLOT( find() ), actionCollection() );
+    TDEAction* acut = KStdAction::cut( this, TQ_SLOT( cut() ), actionCollection() );
+    TDEAction* acopy = KStdAction::copy( this, TQ_SLOT( copy() ), actionCollection() );
+    TDEAction* apaste = KStdAction::paste( this, TQ_SLOT( paste() ), actionCollection() );
+    TDEAction* afind = KStdAction::find( this, TQ_SLOT( find() ), actionCollection() );
     menuBar()->insertItem( i18n("&Edit"), editMenu, -1, 1 );
 
     acut->plug( editMenu );
@@ -93,10 +93,10 @@ void DatabaseBrowser::setupActions()
     
     editMenu->insertSeparator();
     afind->plug( editMenu );
-    KStdAction::findNext( TQT_TQOBJECT(this), TQT_SLOT( findNext() ), actionCollection() )->plug( editMenu );
+    KStdAction::findNext( this, TQ_SLOT( findNext() ), actionCollection() )->plug( editMenu );
     editMenu->insertSeparator();
     TDEAction* aimport = new TDEAction( i18n("&Import CSV File..."), "",
-                                0, TQT_TQOBJECT(this), TQT_SLOT(import()), actionCollection(), "import" );
+                                0, this, TQ_SLOT(import()), actionCollection(), "import" );
     aimport->plug( editMenu );
         
     acut->plug( toolBar() );
@@ -141,7 +141,7 @@ void DatabaseBrowser::find()
     findDlg->setText( m_find );
     findDlg->setDirection( m_direction );
     findDlg->setCaseSensitive( m_case );
-    connect( findDlg, TQT_SIGNAL( search() ), this, TQT_SLOT( findNext() ) );
+    connect( findDlg, TQ_SIGNAL( search() ), this, TQ_SLOT( findNext() ) );
     
     findDlg->exec();
     
