@@ -31,7 +31,7 @@ class MyDataTable;
   * and is mostly used for having a quick look on the tables.
   */
 class DatabaseBrowser : public DSMainWindow{
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         DatabaseBrowser( TQString _database, TQWidget *parent=0, const char *name=0);
