@@ -31,7 +31,7 @@ class TDEPopupMenu;
   * @author Dominik Seichter
   */
 class DSMainWindow : public TDEMainWindow {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         DSMainWindow(TQWidget *parent=0, const char *name=0, WFlags f = WType_TopLevel | WDestructiveClose );
