@@ -28,7 +28,7 @@
 */
 class KBarcodeSettings : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         static KBarcodeSettings* getInstance();
