@@ -28,7 +28,7 @@ class KLineEdit;
 namespace DSSmallDialogs {
 
     class AddAllDialog : public KDialogBase {
-        Q_OBJECT
+        TQ_OBJECT
   
         public:
             AddAllDialog(TQWidget *parent=0, const char *name=0);
@@ -42,7 +42,7 @@ namespace DSSmallDialogs {
     };
 
     class AddItemsDialog : public KDialogBase {
-        Q_OBJECT
+        TQ_OBJECT
   
         public:
             AddItemsDialog( TQWidget* parent = 0, const char* name = 0 );
